# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-18 09:19
from __future__ import unicode_literals

import django.core.files.storage
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0010_auto_20180118_1534'),
    ]

    operations = [
        migrations.CreateModel(
            name='GradeCertField',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180)),
                ('field', models.CharField(max_length=180)),
                ('width', models.IntegerField()),
                ('color', models.CharField(max_length=7)),
            ],
            options={
                'ordering': ['id'],
                'db_table': 'bee_django_exam_grade_cert_field',
            },
        ),
        migrations.AlterField(
            model_name='grade',
            name='cert_image',
            field=models.ImageField(blank=True, null=True, storage=django.core.files.storage.FileSystemStorage(location=b'media/exam/cert'), upload_to=b'', verbose_name='\u8bc1\u4e66\u56fe\u7247'),
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='grade',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_exam.Grade'),
        ),
    ]
