{% extends "bee_django_exam/base.html" %}
{% load bee_django_crm_filter %}
{% block content %}
    <div style="margin: 20px auto;">
        {% if cert_path %}
            <img src="{{ cert_path }}" alt="">
        {% else %}
            <div>未生成图片</div>
        {% endif %}
    </div>
{% endblock %}