# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-18 07:34
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0009_auto_20180118_1520'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userexamrecord',
            name='passed_date',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u901a\u8fc7\u65e5\u671f'),
        ),
    ]
