# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-14 06:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0004_auto_20180114_1415'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userexamrecord',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
    ]
