# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-20 08:05
from __future__ import unicode_literals

import django.core.files.storage
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0015_auto_20180119_1523'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='gradecertfield',
            name='color',
        ),
        migrations.RemoveField(
            model_name='gradecertfield',
            name='width',
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='font_color',
            field=models.CharField(default='#FFFFFF', max_length=7, verbose_name='\u5b57\u4f53\u989c\u8272'),
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='font_size',
            field=models.IntegerField(default=12, max_length=3, verbose_name='\u5b57\u4f53\u5927\u5c0f'),
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='text_align',
            field=models.CharField(default='left', max_length=180, verbose_name='\u6587\u5b57\u5bf9\u9f50'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='text_bg_color',
            field=models.CharField(default='#FFFFFF', max_length=7, verbose_name='\u6587\u5b57\u533a\u57df\u80cc\u666f\u989c\u8272'),
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='text_post_x',
            field=models.IntegerField(default=0, verbose_name='\u6587\u5b57\u533a\u57df\u5de6\u4e0a\u89d2\u6a2a\u5750\u6807'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='text_post_y',
            field=models.IntegerField(default=0, verbose_name='\u6587\u5b57\u533a\u57df\u5de6\u4e0a\u89d2\u7eb5\u5750\u6807'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='text_width',
            field=models.IntegerField(default=100, verbose_name='\u6587\u5b57\u533a\u57df\u5bbd\u5ea6'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='grade',
            name='cert_image',
            field=models.ImageField(blank=True, null=True, storage=django.core.files.storage.FileSystemStorage(base_url='/media/exam/cert', location=b'media/exam/cert'), upload_to=b'', verbose_name='\u8bc1\u4e66\u56fe\u7247'),
        ),
    ]
