# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-19 07:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0013_grade_cert_image'),
    ]

    operations = [
        migrations.AlterField(
            model_name='grade',
            name='cert_image',
            field=models.ImageField(blank=True, null=True, upload_to='static', verbose_name='\u8bc1\u4e66\u56fe\u7247'),
        ),
    ]
