# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-14 07:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0007_userexamrecord_passed_date'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userexamrecord',
            name='is_passed',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u901a\u8fc7'),
        ),
    ]
